%
% Run the DC Permanent Magnet Motor
%
% Note:
% use pathtool or Set Path
% to point to your working directory and include the ~/Primitives directory
%
clear all

global EM_USB;
EM_USB = serial('COM17','Baudrate',115200,'Databits',8);
fopen(EM_USB);

SetActive(0);         % Motor OFF
pause(0.1);
SetCapacitorBank(0);  % OFF
pause(0.1);
SetDynoLoad(127); % Max Resistance = Minimum Load
pause(0.1);
SetSeriesResistor(0); % 0 Ohms
pause(0.1);
SetMotorDirection(0); % Clockwise
pause(0.1);
SetMotorType (0);     % DC Motor
pause(0.1);

api_version = GetAPIVersion();
disp(['api_version = ' , num2str(api_version)]);

switch_state = GetSwitches ();
if switch_state >= 1
   disp('==== DC MOTOR TEST START ====')
   disp('Motor Installed Correctly');
   current_I_DC = GetCurrent(3);
   disp(['DC Current with motor OFF = ' , num2str(current_I_DC) , 'A']);
   pause(0.1);
   motor_voltage = 10; % 10V
   disp(['Setting Motor Voltage to ' , num2str(motor_voltage) , ' Volts']);
   SetVoltage (motor_voltage);
   pause(0.1);
   dyno_load = 20;
   disp(['Setting Dyno Load to ' , num2str(dyno_load) , ' Ohms']);
   SetDynoLoad(dyno_load);
   pause(0.1);
   current_I1 = GetCurrent(4);
   disp(['I1 Current (with Motor OFF) = ' , num2str(current_I1) , 'A']);    
   disp('MOTOR ON');
   time_interval_seconds = 0.1;
   run_time_seconds = 2;
   run_time_elapsed = 0;
   SetActive(1); % Motor ON
   while (run_time_elapsed < run_time_seconds)
      encoder_speed = GetRPM();
      load_cell_grams = GetLoadCell(0);
      current_I1 = GetCurrent(4);
      pause(time_interval_seconds);
      disp(['encoder_speed @ t = ' , num2str(run_time_elapsed) ,' seconds = ', num2str(encoder_speed) , ' RPM LoadCell = ', num2str(load_cell_grams), ' g I1_Current = ' , num2str(current_I1) , 'A' ]);
      run_time_elapsed = run_time_elapsed + time_interval_seconds;
   end
   disp('MOTOR OFF');
   SetActive(0); % Motor OFF
   pause(0.1);  
   disp('==== DC MOTOR TEST END ======');
else    
   disp('==== Motor not fitted in Dynomometer ====');
end

%
% Check for corrupt comms
%
api_version_two = GetAPIVersion();
if api_version == api_version_two
   % do nothing
else
    disp('=== CORRUPT COMMS ===');
    disp(['api_version = ' , num2str(api_version_two) , ' it was ' , num2str(api_version) ] );
end
   
fclose(EM_USB)







