%
% MATLAB_Plot_DC_PM_Speed_Torque.m
% for MATLAB R2018a Update 6 (9.4.0.949201) 64bit (win64) Sept 5,2018
%
% V1.0 - Sean Quinn 22 Jan 2019
%
% Plot the DC Permanent Magnet Motor Speed v Torque characteristics
%
% Note:
% use pathtool or Set Path
% to point to your working directory and include the ~/Primitives directory
%
clear all
clc
global EM_USB;
%
% Find the COM port on your PC where the Matrix EM control unit is plugged
% in and use it here instead of 'COM17'
%
EM_USB = serial('COM17','Baudrate',115200,'Databits',8);
fopen(EM_USB);

SetActive(0);               % Motor OFF
SetMotorType (0);           % DC Motor
motor_voltage = 10;         % 10V DC
dyno_load = 255;            % Dynamometer Load Resistance = 127 Ohms
SetDynoLoad(dyno_load); % Max Resistance = Minimum Load
%
% Test the comms to the control unit before we start
%
api_version = GetAPIVersion();
disp(['api_version = ' , num2str(api_version)]);
%
% Check that the motor is connected to the Dynamometer
%
switch_state = GetSwitches();
if switch_state >= 1
   disp('==== Motor Installed Correctly ====');
   disp(['Setting Motor Voltage to ' , num2str(motor_voltage) , ' Volts']);
   SetVoltage (motor_voltage);
   SetActive(1); % Motor ON
   index = 1;
   pause(1);     % Wait for the motor to spin up
   %
   % Perform the sampled measurements in a tight a loop.
   %
   for loop = 0:127
      load_cell_torque_range(index) = GetLoadCell(1); % Torque in mNm
      encoder_speed_range(index) = GetRPM(); % Speed in RPM
      index = index + 1;
      dyno_load = 127 - loop; 
      SetDynoLoad(dyno_load);
      pause(0.1);
   end
   %
   % Sampling over, turn off the motor
   % and close the COM port
   %
   disp('MOTOR OFF');
   SetActive(0); % Motor OFF
   pause(0.1);
   fclose(EM_USB)
  
   %
   % Plot the Torque v Speed
   %
   curent_torque_plot = figure;
   figure(curent_torque_plot);
   movegui(curent_torque_plot , 'northwest');
   hold on
   p2 = polyfit(encoder_speed_range, load_cell_torque_range , 1); % line of best fit
   y2 = polyval(p2, encoder_speed_range);
   plot(encoder_speed_range, load_cell_torque_range, 'ro', encoder_speed_range, y2, '-r' );
   current_speed_polynomial = poly2sym(p2,sym('T'));
   current_speed_equation = sprintf('Speed = %s',current_speed_polynomial); 
   disp(current_speed_equation);
   grid on
   legend('Samples','Best fit line','Location','northeast');
   xlabel('Speed, RPM');
   ylabel('Torque, mNm');
   title(['PM DC Motor Speed v Torque @ ', num2str(motor_voltage) , 'V']);      
   hold off
   disp('==== Motor Test Finished ====');
else    
   disp('==== Motor not fitted in Dynomometer ====');
end
%
% End MATLAB_Plot_DC_PM_Speed_Torque.m
%
